==> wes-foundation-0.1.0.tgz: package/README.md <==
# `@salesforce-ux/wes-foundation`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/wes-foundation/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/wes-foundation)

## About

A set of foundations supporting the WES Subsystem at Salesforce.
`wes-foundation` package contains the foundational styles  which includes `Typography`, `Font Face`, `Utilities`

## Getting Started
Let's start by installing `wes-foundation` as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/wes-foundation).
```
npm i @salesforce-ux/wes-foundation
```

## Distributable
After installation, all the distributables for the WES Foundation are found under `@salesforce-ux/wes-foundation/dist/` folder.
|File Name |Description |
|- |- |
|`index.css` | The Compiled CSS file for `wes-foundation` package|

## `wes-foundation` Integration

### Dependency Inclusion

[`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) is a styling dependency for `wes-foundation`. Hence, this needs to be embedded into your web app in order to make the `wes-foundation` work properly.

There are different ways [`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) can be embedded. Please checkout the [`wes-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) to learn more.

### Add `wes-foundation`
There are different ways to include `wes-foundation` to a web application depending on the requirement.It can be used in both light DOM and shadow DOM Below are the styles to include the package -

#### Add WES Foundation in HTML
You can use the HTML `<link>` to link to WES Foundation as an external resource.

```html
<html>
  <head>
    <!-- Dependencies go here -->
    <link rel="stylesheet" href="...">
    
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-foundation/dist/index.css">
    <!-- Your application's stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <!-- Your application -->
  </body>
</html>
```

#### Add WES Foundation in CSS
You can use CSS `@imports` to pull in WES Foundation.

```css
@import "@salesforce-ux/wes-foundation/dist/index.css";


```

#### Add WES Foundation in JS
You can use JS `import` to pull in WES Foundation directly in the JS file.

```js
import "@salesforce-ux/wes-foundation/dist/index.css";
```


## Example

Below are a few examples of `Typography` which is part of `wes-foundation`

#### HTML 
```html
<html>
  <head>
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css">
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-foundation/dist/index.css">
    <!-- Your application's stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <h1 type-style="display-1">Title display-1</h1>
    <div type-style="body-1"><p type-style="code">Text body-1 code</p></div>
  </body>
</html>

```

## Interactive Demo
To see more examples with interactive demo, please visit `WES Subsytem`'s [Storybook Environment](https://wes-subsystem-storybook.herokuapp.com/?path=/story/wes-subsystem-foundation-typography--all)

==> wes-foundation-0.1.1.tgz: package/README.md <==
# `@salesforce-ux/wes-foundation`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/wes-foundation/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/wes-foundation)

## About

A set of foundations supporting the WES Subsystem at Salesforce.
`wes-foundation` package contains the foundational styles  which includes `Typography`, `Font Face`, `Utilities`

## Getting Started
Let's start by installing `wes-foundation` as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/wes-foundation).
```
npm i @salesforce-ux/wes-foundation
```

## Distributable
After installation, all the distributables for the WES Foundation are found under `@salesforce-ux/wes-foundation/dist/` folder.
|File Name |Description |
|- |- |
|`index.css` | The Compiled CSS file for `wes-foundation` package|

## `wes-foundation` Integration

### Dependency Inclusion

[`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) is a styling dependency for `wes-foundation`. Hence, this needs to be embedded into your web app in order to make the `wes-foundation` work properly.

There are different ways [`wes-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) can be embedded. Please checkout the [`wes-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/wes-styling-hooks) to learn more.

### Add `wes-foundation`
There are different ways to include `wes-foundation` to a web application depending on the requirement. If you are using the Salesforce Experience Cloud platform, WES is supported through an Unlocked Package, see the [Confluence page for the WES Unlocked Package](https://confluence.internal.salesforce.com/display/CSGT4GG/Website+Experience+Subsystem+%28WES%29+Unlocked+Package). It can be used in both light DOM and shadow DOM.  Below are the styles to include the package -

#### Add WES Foundation in HTML
You can use the HTML `<link>` to link to WES Foundation as an external resource.

```html
<html>
  <head>
    <!-- Dependencies go here -->
    <link rel="stylesheet" href="...">
    
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-foundation/dist/index.css">
    <!-- Your application's stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <!-- Your application -->
  </body>
</html>
```

#### Add WES Foundation in CSS
You can use CSS `@imports` to pull in WES Foundation.

```css
@import "@salesforce-ux/wes-foundation/dist/index.css";


```

#### Add WES Foundation in JS
You can use JS `import` to pull in WES Foundation directly in the JS file.

```js
import "@salesforce-ux/wes-foundation/dist/index.css";
```


## Example

Below are a few examples of `Typography` which is part of `wes-foundation`

#### HTML 
```html
<html>
  <head>
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-styling-hooks/dist/hooks.custom-props.css">
    <link rel="stylesheet" href="/node_modules/@salesforce-ux/wes-foundation/dist/index.css">
    <!-- Your application's stylesheets go below -->
    <link rel="stylesheet" href="...">
  </head>
  <body>
    <h1 type-style="display-1">Title display-1</h1>
    <div type-style="body-1"><p type-style="code">Text body-1 code</p></div>
  </body>
</html>

```

## Interactive Demo
To see more examples with interactive demo, please visit `WES Subsytem`'s [Storybook Environment](https://wes-subsystem-storybook.herokuapp.com/?path=/story/wes-subsystem-foundation-typography--all)
